From 344c48b1f3e7e36a5202e749132e6165ca73b95d Mon Sep 17 00:00:00 2001
From: Coleman Watts <coleman@civicrm.org>
Date: Thu, 21 Jan 2021 09:53:24 -0500
Subject: [PATCH] DAO - Update field labels for activity_contact &
 relationship_cache entities

https://lab.civicrm.org/dev/core/-/issues/2313
---
 CRM/Activity/DAO/ActivityContact.php     | 9 +++++----
 CRM/Contact/DAO/RelationshipCache.php    | 8 +++++++-
 xml/schema/Activity/ActivityContact.xml  | 5 +++--
 xml/schema/Contact/RelationshipCache.xml | 6 ++++++
 4 files changed, 21 insertions(+), 7 deletions(-)

diff --git a/CRM/Contact/DAO/RelationshipCache.php b/CRM/Contact/DAO/RelationshipCache.php
index 5701d5c3e6..c888435bfd 100644
--- a/CRM/Contact/DAO/RelationshipCache.php
+++ b/CRM/Contact/DAO/RelationshipCache.php
@@ -6,7 +6,7 @@
  *
  * Generated from xml/schema/CRM/Contact/RelationshipCache.xml
  * DO NOT EDIT.  Generated by CRM_Core_CodeGen
- * (GenCodeChecksum:ba039fcadc13e48749f965343301ec1d)
+ * (GenCodeChecksum:ec899f1ccb7f617701d7108dc4282691)
  */
 
 /**
@@ -246,6 +246,9 @@ class CRM_Contact_DAO_RelationshipCache extends CRM_Core_DAO {
           'entity' => 'RelationshipCache',
           'bao' => 'CRM_Contact_BAO_RelationshipCache',
           'localizable' => 0,
+          'html' => [
+            'label' => ts("Relationship to contact"),
+          ],
           'pseudoconstant' => [
             'callback' => 'CRM_Core_PseudoConstant::relationshipTypeOptions',
           ],
@@ -280,6 +283,9 @@ class CRM_Contact_DAO_RelationshipCache extends CRM_Core_DAO {
           'entity' => 'RelationshipCache',
           'bao' => 'CRM_Contact_BAO_RelationshipCache',
           'localizable' => 0,
+          'html' => [
+            'label' => ts("Relationship from contact"),
+          ],
           'pseudoconstant' => [
             'callback' => 'CRM_Core_PseudoConstant::relationshipTypeOptions',
           ],
diff --git a/xml/schema/Activity/ActivityContact.xml b/xml/schema/Activity/ActivityContact.xml
index 351b22e047..dc33ce3050 100644
--- a/xml/schema/Activity/ActivityContact.xml
+++ b/xml/schema/Activity/ActivityContact.xml
@@ -53,13 +53,14 @@
   <field>
     <name>record_type_id</name>
     <type>int unsigned</type>
-    <title>Record Type ID</title>
-    <comment>Nature of this contact's role in the activity: 1 assignee, 2 creator, 3 focus or target.</comment>
+    <title>Activity Contact Type</title>
+    <comment>Determines the contact's role in the activity (source, target, or assignee).</comment>
     <pseudoconstant>
       <optionGroupName>activity_contacts</optionGroupName>
     </pseudoconstant>
     <html>
       <type>Select</type>
+      <label>Contact Role</label>
     </html>
     <add>4.4</add>
   </field>
diff --git a/xml/schema/Contact/RelationshipCache.xml b/xml/schema/Contact/RelationshipCache.xml
index 7de6ac766e..023e21e2b2 100644
--- a/xml/schema/Contact/RelationshipCache.xml
+++ b/xml/schema/Contact/RelationshipCache.xml
@@ -93,6 +93,9 @@
     <length>64</length>
     <comment>name for relationship of near_contact to far_contact.</comment>
     <add>5.29</add>
+    <html>
+      <label>Relationship to contact</label>
+    </html>
     <pseudoconstant>
       <callback>CRM_Core_PseudoConstant::relationshipTypeOptions</callback>
     </pseudoconstant>
@@ -124,6 +127,9 @@
     <length>64</length>
     <comment>name for relationship of far_contact to near_contact.</comment>
     <add>5.29</add>
+    <html>
+      <label>Relationship from contact</label>
+    </html>
     <pseudoconstant>
       <callback>CRM_Core_PseudoConstant::relationshipTypeOptions</callback>
     </pseudoconstant>
diff --git a/CRM/Activity/DAO/ActivityContact.php b/CRM/Activity/DAO/ActivityContact.php
index 7f1bfd317f..c789e4f0ed 100644
--- a/CRM/Activity/DAO/ActivityContact.php
+++ b/CRM/Activity/DAO/ActivityContact.php
@@ -6,7 +6,7 @@
  *
  * Generated from xml/schema/CRM/Activity/ActivityContact.xml
  * DO NOT EDIT.  Generated by CRM_Core_CodeGen
- * (GenCodeChecksum:3f147b2507b1e11a7df971be191161d1)
+ * (GenCodeChecksum:1263921d2a6832e26c5a7e34c684e35b)
  */
 
 /**
@@ -52,7 +52,7 @@ class CRM_Activity_DAO_ActivityContact extends CRM_Core_DAO {
   public $contact_id;
 
   /**
    * Nature of this contact's role in the activity: 1 assignee, 2 creator, 3 focus or target.
    *
    * @var int
    */
@@ -146,8 +146,8 @@ class CRM_Activity_DAO_ActivityContact extends CRM_Core_DAO {
         'record_type_id' => [
           'name' => 'record_type_id',
           'type' => CRM_Utils_Type::T_INT,
-          'title' => ts('Record Type ID'),
-          'description' => ts('Nature of this contact\'s role in the activity: 1 assignee, 2 creator, 3 focus or target.'),
+          'title' => ts('Activity Contact Type'),
+          'description' => ts('Determines the contact\'s role in the activity (source, target, or assignee).'),
           'where' => 'civicrm_activity_contact.record_type_id',
           'table_name' => 'civicrm_activity_contact',
           'entity' => 'ActivityContact',
@@ -155,6 +155,7 @@ class CRM_Activity_DAO_ActivityContact extends CRM_Core_DAO {
           'localizable' => 0,
           'html' => [
             'type' => 'Select',
+            'label' => ts("Contact Role"),
           ],
           'pseudoconstant' => [
             'optionGroupName' => 'activity_contacts',
@@ -52,7 +52,7 @@ class CRM_Activity_DAO_ActivityContact extends CRM_Core_DAO {
 
   /**
-   * Nature of this contact's role in the activity: 1 assignee, 2 creator, 3 focus or target.
+   * Determines the contact's role in the activity (source, target, or assignee).
    *
    * @var int
-- 
2.25.1